Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶ added in v0.0.6
type Config struct {
// Name is the identifier for the agent
Name string
// Description provides details about the agent's purpose
Description string
// SystemInstructions defines the agent's behavior and role
SystemInstructions string
// EngineURL is the base URL for the model inference engine
EngineURL string
// APIKey
APIKey string
KeepConversationHistory bool
}
Config represents the core configuration parameters for creating an agent
type Kind ¶
type Kind string
AgentKind represents the type of agent
const ( Basic Kind = "Basic" Chat Kind = "Chat" ChatServer Kind = "ChatServer" Remote Kind = "Remote" Tools Kind = "Tools" Orchestrator Kind = "Orchestrator" Rag Kind = "Rag" Compressor Kind = "Compressor" Structured Kind = "Structured" Macro Kind = "Macro" Composite Kind = "Composite" Tasks Kind = "Tasks" )
type OrchestratorAgent ¶ added in v1.0.8
type OrchestratorAgent interface {
// IdentifyIntent sends messages and returns the identified intent
IdentifyIntent(userMessages []messages.Message) (intent *Intent, finishReason string, err error)
// IdentifyTopicFromText is a convenience method that takes a text string and returns the topic
IdentifyTopicFromText(text string) (string, error)
// GetAgentForTopic returns the agent ID for a given topic based on routing configuration
// Returns empty string if no routing config is set or no match is found
GetAgentForTopic(topic string) string
}
OrchestratorAgent is an interface for agents that can identify intents/topics from user input
type Task ¶ added in v1.3.4
type Task struct {
ID string `json:"id"`
Description string `json:"description"`
Responsible string `json:"responsible"`
ToolName string `json:"tool_name,omitempty"`
Arguments map[string]string `json:"arguments,omitempty"`
DependsOn []string `json:"depends_on,omitempty"`
Complexity string `json:"complexity,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.